@@ -4,13 +4,13 @@ import shutil
 import glob
 import AdaptivePELE.adaptiveSampling as adt
 import PPP.main as ppp
+import pele_platform.Utilities.Helpers.plop_launcher as plop
 from pele_platform.Utilities.Helpers import helpers
 import pele_platform.Utilities.Parameters.pele_env as pele
 import pele_platform.Utilities.Helpers.constraints as ct
 import pele_platform.constants.constants as cs
 import pele_platform.Utilities.Helpers.system_prep as sp
 import pele_platform.Utilities.Helpers.prepwizard as pp
-import pele_platform.Utilities.PlopRotTemp.launcher as plop
 import pele_platform.Utilities.Helpers.missing_residues as mr
 import pele_platform.Utilities.Helpers.simulation as ad
 import pele_platform.Utilities.Helpers.center_of_mass as cm
@@ -19,6 +19,7 @@ import pele_platform.Utilities.Helpers.helpers as hp
 import pele_platform.Utilities.Helpers.metrics as mt
 import pele_platform.Utilities.Helpers.external_files as ext
 import pele_platform.Utilities.Helpers.solventOBCParamsGenerator as obc
+import pele_platform.Utilities.Helpers.calculatePCA4PELE as pc
 import pele_platform.Analysis.plots as pt
 
 
@@ -27,9 +28,10 @@ import pele_platform.Analysis.plots as pt
 def run_adaptive(args):
     # Build Folders and Logging and env variable that will containt
     #all main  attributes of the simulation
-    env = pele.EnviroBuilder.build_env(args)
+    env = pele.EnviroBuilder()
     env.software = "Adaptive"
-
+    env.build_adaptive_variables(args)
+    env.create_files_and_folders()
     shutil.copy(args.yamlfile, env.pele_dir) 
 
     if env.adaptive_restart and not env.only_analysis:
@@ -41,43 +43,43 @@ def run_adaptive(args):
 
         ##PREPWIZARD##
         if args.prepwizard:
-            args.system = pp.run_prepwizard(args.system) 
+            env.system = pp.run_prepwizard(env.system) 
 
 
         env.logger.info("System: {}; Platform Functionality: {}\n\n".format(env.residue, env.software))
         
         if env.perturbation:
-            syst = sp.SystemBuilder.build_system(args.system, args.mae_lig, args.residue, env.pele_dir)
+            syst = sp.SystemBuilder.build_system(env.system, args.mae_lig, args.residue, env.pele_dir)
         else:
-            syst = sp.SystemBuilder(args.system, None, None, env.pele_dir)
+            syst = sp.SystemBuilder(env.system, None, None, env.pele_dir)
         
         env.logger.info("Prepare complex {}".format(syst.system))
         ########Choose your own input####################
-        if args.input:
+        # User specifies more than one input
+        if env.input:
             env.inputs_simulation = []
             for input in env.input:
                 input_path  = os.path.join(env.pele_dir, os.path.basename(input))
                 shutil.copy(input, input_path)
-                input_proc = os.path.basename(ppp.main(input_path, env.pele_dir, output_pdb=["" , ],
+                if env.no_ppp:
+                    input_proc = input
+                else:
+                    input_proc = os.path.basename(ppp.main(input_path, env.pele_dir, output_pdb=["" , ],
                                 charge_terminals=args.charge_ter, no_gaps_ter=args.gaps_ter,
-                                constrain_smiles=env.constrain_smiles)[0], ligand_pdb=env.ligand_ref)
+                                constrain_smiles=env.constrain_smiles, ligand_pdb=env.ligand_ref)[0])
                 env.inputs_simulation.append(input_proc)
                 hp.silentremove([input_path])
-            env.adap_ex_input = ", ".join(['"' + input +  '"' for input in env.inputs_simulation])
+            env.adap_ex_input = ", ".join(['"' + input + '"' for input in env.inputs_simulation]).strip('"')
+        # Global exploration mode: Create inputs around protein
         elif args.full or args.randomize:
-            command = "{} {} --ligand {} --receptor {} --resname {} --poses {} --output_folder {}".format(
-            cs.PYMOL_PYTHON, os.path.join(cs.DIR, "Utilities/Helpers/randomize.py"), env.ligand_ref,
-            env.receptor, env.residue, env.poses, env.pele_dir)
-            print(command)
-            outputs = subprocess.check_output(command.split())
-            #Get stdout as variables (specific format decided by me)
-            ligand_positions = [l.strip().strip("'") for l in str(outputs).split(";")[-3].strip(" ['").strip("']").split(",")]
-            box_radius = float(str(outputs).split(";")[-1].strip('\\n"').strip())
-            box_center = [float(c) for c in str(outputs).split(";")[-2].strip(" [").strip("]").split(",")]
-            # Use choice stays as first priority
+            ligand_positions, box_radius, box_center = rd.randomize_starting_position(env.ligand_ref, env.receptor,
+                outputfolder=env.pele_dir, nposes=env.poses, test=env.test)
             env.box_center = box_center if not env.box_center else env.box_center
             env.box_radius = box_radius if not env.box_radius else env.box_radius
-            receptor = ppp.main(syst.system, env.pele_dir, output_pdb=["" , ],
+            if env.no_ppp:
+                receptor = syst.system
+            else:
+                receptor = ppp.main(syst.system, env.pele_dir, output_pdb=["" , ],
                             charge_terminals=args.charge_ter, no_gaps_ter=args.gaps_ter,
                             constrain_smiles=env.constrain_smiles, ligand_pdb=env.ligand_ref)[0]
             inputs = rd.join(receptor, ligand_positions, env.residue, output_folder=env.pele_dir)
@@ -87,21 +89,24 @@ def run_adaptive(args):
 
         ##########Prepare System################
         if env.no_ppp:
-            env.adap_ex_input = system_fix = syst.system
             missing_residues = []
             gaps = {}
             metals = {}
-            env.constraints = ct.retrieve_constraints(system_fix, gaps, metals, back_constr=env.ca_constr)
-            shutil.copy(env.adap_ex_input, env.pele_dir)
+            env.constraints = ct.retrieve_constraints(env.system, gaps, metals, back_constr=env.ca_constr)
+            if env.input:
+                # If we have more than one input
+                for input in env.input: shutil.copy(input, env.pele_dir)
+            else:
+                shutil.copy(env.system, env.pele_dir)
         else:
-            system_fix, missing_residues, gaps, metals, env.constraints = ppp.main(syst.system, env.pele_dir, output_pdb=["" , ], charge_terminals=args.charge_ter, no_gaps_ter=args.gaps_ter, mid_chain_nonstd_residue=env.nonstandard, skip=env.skip_prep, back_constr=env.ca_constr, constrain_smiles=env.constrain_smiles, ligand_pdb=env.ligand_ref)
+            env.system, missing_residues, gaps, metals, env.constraints = ppp.main(syst.system, env.pele_dir, output_pdb=["" , ], charge_terminals=args.charge_ter, no_gaps_ter=args.gaps_ter, mid_chain_nonstd_residue=env.nonstandard, skip=env.skip_prep, back_constr=env.ca_constr, constrain_smiles=env.constrain_smiles, ligand_pdb=env.ligand_ref)
         if env.external_constraints:
             # Keep Json ordered by having first title and then constraints
             env.constraints = env.constraints[0:1] + env.external_constraints + env.constraints[1:]
         if env.remove_constraints:
             env.constraints = ""
         env.logger.info(cs.SYSTEM.format(missing_residues, gaps, metals))
-        env.logger.info("Complex {} prepared\n\n".format(system_fix))
+        env.logger.info("Complex {} prepared\n\n".format(env.system))
 
         ############Build metrics##################
         env.logger.info("Setting metrics")
@@ -162,21 +167,23 @@ def run_adaptive(args):
            elif isinstance(env.pca_traj, list):
                pdbs = env.pca_traj
            pdbs_full_path = [os.path.abspath(pdb) for pdb in pdbs]
-           output = os.path.basename(pdbs[0])[:-4] + "_ca_pca_modes.nmd"
-           pca_script = os.path.join(cs.DIR, "Utilities/Helpers/calculatePCA4PELE.py")
-           command = 'python {} --pdb "{}"'.format(pca_script, " ".join(pdbs_full_path))
            with helpers.cd(env.pele_dir):
-               os.system(command)
-           env.pca = cs.PCA.format(output)
+               pca = pc.main(pdbs_full_path)
+           env.pca = cs.PCA.format(pca)
 
         
         ############Fill in Simulation Templates############
         env.logger.info("Running Simulation")
-        if env.adaptive:
-            ext.external_adaptive_file(env)
-        if env.pele:
-            ext.external_pele_file(env)
+        #if env.adaptive:
+        #    ext.external_adaptive_file(env)
+        #if env.pele:
+        #    ext.external_pele_file(env)
         adaptive = ad.SimulationBuilder(env.ad_ex_temp, env.pele_exit_temp, env)
+        # Fill to time because we have flags inside flags
+        adaptive.fill_pele_template(env)
+        adaptive.fill_pele_template(env)
+        adaptive.fill_adaptive_template(env)
+        adaptive.fill_adaptive_template(env)
         if not env.debug:
             adaptive.run()
         env.logger.info("Simulation run succesfully (:\n\n")
