@@ -5,62 +5,8 @@ import os
 # USER TO CHANGE
 ###########################
 
-machine = socket.getfqdn()
-if "bsc.mn" in machine:
-    SCHRODINGER = "/gpfs/projects/bsc72/SCHRODINGER_ACADEMIC"
-    PELE = "/gpfs/projects/bsc72/PELE++/nord/rev090518"
-    PELE_BIN = "PELE-1.5_mpi"
-    MPIRUN = "/apps/INTEL/2017.4/impi/2017.3.196/bin64"
-    LICENSE = "/gpfs/projects/bsc72/PELE++/license"
-    MMSHARE = None
-    # Provisional workaround until best_struct.py is fixed
-    ACCEPTED_STEPS_NAME = "numberOfAcceptedPeleSteps"
-    CRITERIA = "sasaLig"
-
-elif "mn.bsc" in machine:
-    SCHRODINGER = "/gpfs/projects/bsc72/SCHRODINGER_ACADEMIC_NORD"
-    PELE = "/gpfs/projects/bsc72/PELE++/nord/rev090518"
-    PELE_BIN = "PELE-1.5_mpi"
-    MPIRUN = "/apps/OPENMPI/1.8.1-mellanox/bin"
-    LICENSE = "/gpfs/projects/bsc72/PELE++/license"
-    MMSHARE = None
-    # Provisional workaround until best_struct.py is fixed
-    ACCEPTED_STEPS_NAME = "AcceptedSteps"
-    CRITERIA = "SASA"
-
-elif "bsccv" in machine:
-    SCHRODINGER = "/data2/bsc72/SCHRODINGER_ACADEMIC"
-    PELE = "/data/EAPM/PELE/PELE++/life/rev12489"
-    PELE_BIN = "PELE-1.5_mpi"
-    MPIRUN = "/data2/apps/OPENMPI/1.6.1/bin"
-    #LICENSE = "/gpfs/projects/bsc72/PELE++/license"
-    MMSHARE = None
-    LICENSE = "/data/EAPM/PELE/PELE++/license"
-    # MMSHARE = "/data2/bsc72/SCHRODINGER_ACADEMIC/mmshare-v3.9/bin/Linux-x86_64"
-    # SCHRODINGER_PYTHON_LIBS = "/data2/bsc72/SCHRODINGER_ACADEMIC/mmshare-v3.9/lib/Linux-x86_64/lib/python2.7/site-packages/"
-    # Provisional workaround until best_struct.py is fixed
-    ACCEPTED_STEPS_NAME = "AcceptedSteps"
-    CRITERIA = "SASA"
-elif "nbdcalc" in machine:
-    SCHRODINGER = "/opt/schrodinger2019-1/"
-    PELE = "/home/dsoler/local_deps/PELE-repo/"
-    PELE_BIN = "/home/dsoler/local_deps/PELE-repo/build/PELE-1.6"
-    MPIRUN = "/usr/lib64/openmpi/bin/"
-    LICENSE = "/home/dsoler"
-    MMSHARE = None
-    # Provisional workaround until best_struct.py is fixed
-    ACCEPTED_STEPS_NAME = "numberOfAcceptedPeleSteps"
-else:
-    SCHRODINGER = "/sNow/easybuild/centos/7.4.1708/Skylake/software/schrodinger2017-4/"
-    PYMOL_PYTHON = "/sNow/easybuild/centos/7.4.1708/Skylake/software/PyMOL/2.2.0_0/bin/python"
-    PELE = "/sNow/easybuild/centos/7.4.1708/Skylake/software/PELE/1.5.0.2524/"
-    PELE_BIN = "/sNow/easybuild/centos/7.4.1708/Skylake/software/PELE/1.5.0.2524-intel-2018a/bin/Pele_mpi"
-    MPIRUN = "/sNow/easybuild/centos/7.4.1708/Skylake/software/OpenMPI/2.1.2-GCC-6.4.0-2.28/bin/"
-    LICENSE = "/work/NBD_Utilities/PELE/licenses"
-    MMSHARE = None
-    # Provisional workaround until best_struct.py is fixed
-    ACCEPTED_STEPS_NAME = "numberOfAcceptedPeleSteps"
-    CRITERIA = "sasaLig"
+SCHRODINGER = os.environ.get("SCHRODINGER", "")
+PELE = os.environ.get("PELE", "")
 
 
 
